==> kdeutils_4.1.2.orig.tar.gz: kdeutils-4.1.2/okteta/program/oktetakakao/controllers/view/libbytearrayfilter/filter/reversebytearrayfilter.h <==
/*
    This file is part of the Okteta Kakao module, part of the KDE project.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef REVERSEBYTEARRAYFILTER_H
#define REVERSEBYTEARRAYFILTER_H

//
#include "reversebytearrayfilterparameterset.h"
//
#include <abstractbytearrayfilter.h>


class ReverseByteArrayFilter : public AbstractByteArrayFilter
{
  public:
    ReverseByteArrayFilter();
    virtual ~ReverseByteArrayFilter();

  public: // AbstractByteArrayFilter API
    virtual bool filter( char *result, KHECore::KAbstractByteArrayModel *model, const KHE::KSection &section ) const;
    virtual AbstractByteArrayFilterParameterSet *parameterSet();

  protected:
    ReverseByteArrayFilterParameterSet mParameterSet;
};

#endif

==> kdeutils_4.2.2.orig.tar.gz: kdeutils-4.2.2/okteta/program/oktetakakao/controllers/view/libbytearrayfilter/filter/reversebytearrayfilter.h <==
/*
    This file is part of the Okteta Kakao module, part of the KDE project.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef REVERSEBYTEARRAYFILTER_H
#define REVERSEBYTEARRAYFILTER_H

//
#include "reversebytearrayfilterparameterset.h"
//
#include <abstractbytearrayfilter.h>


class ReverseByteArrayFilter : public AbstractByteArrayFilter
{
  public:
    ReverseByteArrayFilter();
    virtual ~ReverseByteArrayFilter();

  public: // AbstractByteArrayFilter API
    virtual bool filter( char *result, KHECore::AbstractByteArrayModel *model, const KHE::Section &section ) const;
    virtual AbstractByteArrayFilterParameterSet *parameterSet();

  protected:
    ReverseByteArrayFilterParameterSet mParameterSet;
};

#endif
